@@ -1,4 +1,4 @@
-/* $XFree86: test/xsuite/xtest/src/bin/mc/main.c,v 1.3 2005/02/25 18:06:59 dawes Exp $ */
+/* $XFree86: test/xsuite/xtest/src/bin/mc/main.c,v 1.4 2005/10/05 00:46:30 dawes Exp $ */
 /*
  
 Copyright (c) 1990, 1991  X Consortium
@@ -37,16 +37,16 @@ in this Software without prior written authorization from the X Consortium.
  * makes no representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied warranty.
  *
- * $XConsortium: main.c,v 1.9 94/04/17 21:00:22 rws Exp $
- *
  * Author: Steve Ratcliffe, UniSoft Ltd.
  */
 
 #include	<stdio.h>
 #include	<stdlib.h>
+#include	<string.h>
 #include	<sys/types.h>
 #include	<signal.h>
 #include	<ctype.h>
+#include	<unistd.h>
 
 #include "mc.h"
 
