@@ -1,3 +1,4 @@
+/* $XFree86: test/xsuite/xtest/src/libproto/XstIO.c,v 1.6 2005/10/05 00:46:32 dawes Exp $ */
 /*
  
 Copyright (c) 1990, 1991  X Consortium
@@ -36,7 +37,6 @@ in this Software without prior written authorization from the X Consortium.
  * makes no representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied warranty.
  *
- * $XConsortium: XstIO.c,v 1.11 94/04/17 21:01:38 rws Exp $
  */
 /*
  * ***************************************************************************
@@ -62,7 +62,8 @@ in this Software without prior written authorization from the X Consortium.
  *  SOFTWARE.                                                                *
  * ***************************************************************************
  */
-/* $XFree86: test/xsuite/xtest/src/libproto/XstIO.c,v 1.5 2004/01/01 21:47:10 dawes Exp $ */
+
+#include <unistd.h>
 
 #include "XstlibInt.h"
 #include "XstosInt.h"
