@@ -1,4 +1,4 @@
-/* $XFree86: test/xsuite/xtest/tset/CH02/clsdsply/clsdsply.m,v 1.2 2000/05/12 00:31:17 tsi Exp $ */
+/* $XFree86: test/xsuite/xtest/tset/CH02/clsdsply/clsdsply.m,v 1.3 2005/10/05 00:46:33 dawes Exp $ */
 /*
  
 Copyright (c) 1990, 1991  X Consortium
@@ -37,7 +37,6 @@ in this Software without prior written authorization from the X Consortium.
  * makes no representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied warranty.
  *
- * $XConsortium: clsdsply.m,v 1.25 94/04/17 21:02:04 rws Exp $
  */
 >>TITLE XCloseDisplay CH02
 
@@ -45,7 +44,7 @@ XCloseDisplay(display)
 Display	*display = Dsp;
 >>EXTERN
 
-#include	"string.h"
+#include	<string.h>
 #include	"Xatom.h"
 
 #define PROTECT(x)	_startcall(display);\
