@@ -1,3 +1,4 @@
+/* $XFree86: test/xsuite/xtest/tset/CH02/opndsply/opndsply.m,v 1.2 2005/10/05 00:46:33 dawes Exp $ */
 /*
  
 Copyright (c) 1990, 1991  X Consortium
@@ -36,7 +37,6 @@ in this Software without prior written authorization from the X Consortium.
  * makes no representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied warranty.
  *
- * $XConsortium: opndsply.m,v 1.17 94/04/17 21:02:37 rws Exp $
  */
 >>TITLE XOpenDisplay CH02
 Display *
@@ -68,7 +68,7 @@ Test1 : Test1.o $(LIBS) $(TCMCHILD)
 # End of section copied from the .m file.
 #
 >>EXTERN
-#include	"ctype.h"
+#include	<ctype.h>
 #include	"Xatom.h"
 static char *copystring (src, len) /* Courtesy of Xlib. */
     char *src;
