@@ -1,3 +1,4 @@
+/* $XFree86: test/xsuite/xtest/tset/CH05/strclr/strclr.m,v 1.2 2005/09/13 01:56:19 dawes Exp $ */
 /*
  
 Copyright (c) 1990, 1991  X Consortium
@@ -36,7 +37,6 @@ in this Software without prior written authorization from the X Consortium.
  * makes no representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied warranty.
  *
- * $XConsortium: strclr.m,v 1.18 94/04/17 21:04:14 rws Exp $
  */
 >>TITLE XStoreColor CH05
 void
@@ -475,21 +475,21 @@ XColor		*refp;
 unsigned long	*reds, *greens, *blues;
 int		pathcnt = 0;
 static XColor triples[] = {
-		(unsigned long)~0L, 0,0,0, DoRed|DoGreen|DoBlue, 0,
-		(unsigned long)~0L, 1,0,0, DoRed|DoGreen|DoBlue, 0,
-		(unsigned long)~0L, 0,1,0, DoRed|DoGreen|DoBlue, 0,
-		(unsigned long)~0L, 0,0,1, DoRed|DoGreen|DoBlue, 0,
-		(unsigned long)~0L, 3,2,1, DoRed|DoGreen|DoBlue, 0,
-		(unsigned long)~0L, 1,3,0, DoRed|DoGreen|DoBlue, 0,
-		(unsigned long)~0L, 7,3,1, DoRed|DoGreen|DoBlue, 0,
-		(unsigned long)~0L, 7,8,5, DoRed|DoGreen|DoBlue, 0,
-		(unsigned long)~0L, 15,11,12, DoRed|DoGreen|DoBlue, 0,
-		(unsigned long)~0L, 42,99,13, DoRed|DoGreen|DoBlue, 0,
-		(unsigned long)~0L, 112,127,64, DoRed|DoGreen|DoBlue, 0,
-		(unsigned long)~0L, 255,64,33, DoRed|DoGreen|DoBlue, 0,
-		(unsigned long)~0L, 64,255,33, DoRed|DoGreen|DoBlue, 0,
-		(unsigned long)~0L, 64,33,255, DoRed|DoGreen|DoBlue, 0,
-		(unsigned long)~0L, 255,255,255, DoRed|DoGreen|DoBlue, 0
+		{ (unsigned long)~0L, 0,0,0, DoRed|DoGreen|DoBlue, 0 },
+		{ (unsigned long)~0L, 1,0,0, DoRed|DoGreen|DoBlue, 0 },
+		{ (unsigned long)~0L, 0,1,0, DoRed|DoGreen|DoBlue, 0 },
+		{ (unsigned long)~0L, 0,0,1, DoRed|DoGreen|DoBlue, 0 },
+		{ (unsigned long)~0L, 3,2,1, DoRed|DoGreen|DoBlue, 0 },
+		{ (unsigned long)~0L, 1,3,0, DoRed|DoGreen|DoBlue, 0 },
+		{ (unsigned long)~0L, 7,3,1, DoRed|DoGreen|DoBlue, 0 },
+		{ (unsigned long)~0L, 7,8,5, DoRed|DoGreen|DoBlue, 0 },
+		{ (unsigned long)~0L, 15,11,12, DoRed|DoGreen|DoBlue, 0 },
+		{ (unsigned long)~0L, 42,99,13, DoRed|DoGreen|DoBlue, 0 },
+		{ (unsigned long)~0L, 112,127,64, DoRed|DoGreen|DoBlue, 0 },
+		{ (unsigned long)~0L, 255,64,33, DoRed|DoGreen|DoBlue, 0 },
+		{ (unsigned long)~0L, 64,255,33, DoRed|DoGreen|DoBlue, 0 },
+		{ (unsigned long)~0L, 64,33,255, DoRed|DoGreen|DoBlue, 0 },
+		{ (unsigned long)~0L, 255,255,255, DoRed|DoGreen|DoBlue, 0 }
 	};
 
 /* If visual class DirectColor is supported: */
